@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::Cache;
 use vars '$VERSION';
-$VERSION = '0.994';
+$VERSION = '0.995';
 
 use base 'XML::Compile::Schema';
 
@@ -21,6 +21,8 @@ use XML::LibXML::Simple  qw/XMLin/;
 
 sub init($)
 {   my ($self, $args) = @_;
+    $self->addPrefixes($args->{prefixes});
+
     $self->SUPER::init($args);
 
     $self->{XCC_opts}   = delete $args->{opts_rw}      || [];
@@ -38,7 +40,6 @@ sub init($)
     $self->{XCC_readers} = {};
     $self->{XCC_writers} = {};
 
-    $self->prefixes($args->{prefixes});
     $self->typemap($args->{typemap});
     $self->xsiType($args->{xsi_type});
     $self->anyElement($args->{any_element} || 'SKIP_ALL');
@@ -105,7 +106,7 @@ sub anyElement($)
 #----------------------
 
 
-sub prefixes(@)
+sub addPrefixes(@)
 {   my $self  = shift;
     my $p     = $self->{XCC_namespaces} ||= {};
     my $first = shift;
@@ -117,8 +118,9 @@ sub prefixes(@)
       : ref $first eq 'ARRAY' ? @$first
       : ref $first eq 'HASH'  ? %$first
       : error __x"prefixes() expects list of PAIRS, an ARRAY or a HASH";
+# warn "new prefixes: @pairs\n";
 
-    my $a    = $self->{XCC_prefixes}   ||= {};
+    my $a    = $self->{XCC_prefixes} ||= {};
     while(@pairs)
     {   my ($prefix, $ns) = (shift @pairs, shift @pairs);
         $p->{$ns} ||= { uri => $ns, prefix => $prefix, used => 0 };
@@ -138,8 +140,19 @@ sub prefixes(@)
 }
 
 
+
+sub prefixes(@)
+{   my $self = shift;
+    return $self->addPrefixes(@_) if @_;
+    $self->{XCC_namespaces} || {};
+}
+
+
 sub prefix($) { $_[0]->{XCC_prefixes}{$_[1]} }
 
+# [0.995] should this be public?
+sub byPrefixTable() { shift->{XCC_prefixes} }
+
 
 sub prefixFor($)
 {   my $def = $_[0]->{XCC_namespaces}{$_[1]} or return ();
@@ -161,7 +174,7 @@ sub learnPrefixes($)
         {   next PREFIX if $def->{uri} eq $uri;
         }
         else
-        {   $self->prefixes($prefix => $uri);
+        {   $self->addPrefixes($prefix => $uri);
             next PREFIX;
         }
 
@@ -170,7 +183,7 @@ sub learnPrefixes($)
         {   next PREFIX if $def->{uri} eq $uri;
             $prefix++;
         }
-        $self->prefixes($prefix => $uri);
+        $self->addPrefixes($prefix => $uri);
     }
 }
 
@@ -539,12 +552,11 @@ sub _convertAnyTyped(@)
     {   trace "cannot auto-convert 'any': ".$@->wasFatal->message;
         return ($key => $nodes);
     }
-    trace "auto-convert known type 'any' $type";
+    trace "auto-convert known type for 'any': $type";
 
     my @nodes   = ref $nodes eq 'ARRAY' ? @$nodes : $nodes;
-    my @convert = map {$reader->($_)} @nodes;
-
-    ($key => @convert==1 ? $convert[0] : \@convert);
+    my @convert = map $reader->($_), @nodes;
+    ($key => (@convert==1 ? $convert[0] : \@convert) );
 }
 
 sub _convertAnySloppy(@)
